@@ -453,7 +453,7 @@ class Formatter:
         brace_found = False
         brace_count = 0
         while not (brace_found and brace_count == 0):
-            if self.__tokens[pos].get_value() in params and Formatter.__is_not_lower_camel_case(self.__tokens[pos]):
+            if self.__tokens[pos].get_value() in params and Formatter.__is_not_lower_camel_case(self.__tokens[pos].get_value()):
                 self.__tokens[pos].set_fixed_value(
                     Formatter.snake_to_lower_camel_case(self.__tokens[pos].get_value()))
             elif self.__tokens[pos].get_value() == '{':
